@@ -1,8 +1,9 @@
 from __future__ import annotations
 
 import locale
-from argparse import ArgumentParser, FileType, HelpFormatter, Namespace
+from argparse import ArgumentParser, HelpFormatter, Namespace
 from operator import attrgetter
+from pathlib import Path
 from typing import TYPE_CHECKING
 
 from datamodel_code_generator import DataModelType, InputFileType, OpenAPIScope
@@ -417,7 +418,7 @@ field_options.add_argument(
 template_options.add_argument(
     "--aliases",
     help="Alias mapping file",
-    type=FileType("rt"),
+    type=Path,
 )
 template_options.add_argument(
     "--custom-file-header",
@@ -448,7 +449,7 @@ template_options.add_argument(
     "apply the template data to multiple objects with the same name. "
     "If you are using another input file type (e.g. GraphQL), the key is the name of the object. "
     "The value is a dictionary of the template data to add.",
-    type=FileType("rt"),
+    type=Path,
 )
 template_options.add_argument(
     "--use-double-quotes",
@@ -485,7 +486,7 @@ base_options.add_argument(
 template_options.add_argument(
     "--custom-formatters-kwargs",
     help="A file with kwargs for custom formatters.",
-    type=FileType("rt"),
+    type=Path,
 )
 
 # ======================================================================================
