@@ -59,7 +59,7 @@ def test_main(tmp_path: Path) -> None:
         str(output_file),
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "general.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "general.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -82,7 +82,7 @@ def test_main_openapi_discriminator_enum(tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "discriminator" / "enum.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "discriminator" / "enum.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -105,7 +105,10 @@ def test_main_openapi_discriminator_enum_duplicate(tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "discriminator" / "enum_duplicate.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "discriminator" / "enum_duplicate.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -121,7 +124,10 @@ def test_main_openapi_discriminator_with_properties(tmp_path: Path) -> None:
     ])
     assert return_code == Exit.OK
 
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "discriminator" / "with_properties.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "discriminator" / "with_properties.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -136,7 +142,7 @@ def test_main_pydantic_basemodel(tmp_path: Path) -> None:
         "pydantic.BaseModel",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "general.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "general.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -152,7 +158,7 @@ def test_main_base_class(tmp_path: Path) -> None:
         "custom_module.Base",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "base_class.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "base_class.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -167,7 +173,7 @@ def test_target_python_version(tmp_path: Path) -> None:
         f"3.{MIN_VERSION}",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "target_python_version.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "target_python_version.py").read_text()
 
 
 @pytest.mark.benchmark
@@ -361,7 +367,7 @@ def test_pyproject(tmp_path: Path) -> None:
 
         return_code: Exit = main([])
         assert return_code == Exit.OK
-        assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "pyproject.py").read_text()
+        assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "pyproject.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -375,7 +381,7 @@ def test_pyproject_not_found(tmp_path: Path) -> None:
             str(output_file),
         ])
         assert return_code == Exit.OK
-        assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "pyproject_not_found.py").read_text()
+        assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "pyproject_not_found.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -387,7 +393,7 @@ def test_stdin(monkeypatch: pytest.MonkeyPatch, tmp_path: Path) -> None:
         str(output_file),
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "stdin.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "stdin.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -403,7 +409,7 @@ def test_validation(mocker: MockerFixture, tmp_path: Path) -> None:
         "--validation",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "validation.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "validation.py").read_text()
     mock_prance.assert_called_once()
 
 
@@ -474,7 +480,7 @@ def test_main_with_field_constraints(output_model: str, expected_output: str, ar
         *args,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 @pytest.mark.parametrize(
@@ -502,7 +508,7 @@ def test_main_without_field_constraints(output_model: str, expected_output: str,
         output_model,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 @pytest.mark.parametrize(
@@ -538,7 +544,7 @@ def test_main_with_aliases(output_model: str, expected_output: str, tmp_path: Pa
         str(output_file),
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 def test_main_with_bad_aliases(tmp_path: Path) -> None:
@@ -592,7 +598,7 @@ def test_main_with_snake_case_field(tmp_path: Path) -> None:
         "--snake-case-field",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "with_snake_case_field.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "with_snake_case_field.py").read_text()
 
 
 @pytest.mark.benchmark
@@ -607,7 +613,7 @@ def test_main_with_strip_default_none(tmp_path: Path) -> None:
         "--strip-default-none",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "with_strip_default_none.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "with_strip_default_none.py").read_text()
 
 
 def test_disable_timestamp(tmp_path: Path) -> None:
@@ -620,7 +626,7 @@ def test_disable_timestamp(tmp_path: Path) -> None:
         "--disable-timestamp",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "disable_timestamp.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "disable_timestamp.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -636,7 +642,7 @@ def test_enable_version_header(tmp_path: Path) -> None:
     assert return_code == Exit.OK
     expected = (EXPECTED_OPENAPI_PATH / "enable_version_header.py").read_text()
     expected = expected.replace("#   version:   0.0.0", f"#   version:   {get_version()}")
-    assert output_file.read_text() == expected
+    assert output_file.read_text(encoding="utf-8") == expected
 
 
 @pytest.mark.parametrize(
@@ -669,7 +675,7 @@ def test_allow_population_by_field_name(output_model: str, expected_output: str,
         output_model,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 @pytest.mark.parametrize(
@@ -702,7 +708,7 @@ def test_allow_extra_fields(output_model: str, expected_output: str, tmp_path: P
         output_model,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 @pytest.mark.parametrize(
@@ -735,7 +741,7 @@ def test_enable_faux_immutability(output_model: str, expected_output: str, tmp_p
         output_model,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 @pytest.mark.benchmark
@@ -750,7 +756,7 @@ def test_use_default(tmp_path: Path) -> None:
         "--use-default",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "use_default.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "use_default.py").read_text()
 
 
 @pytest.mark.benchmark
@@ -765,7 +771,7 @@ def test_force_optional(tmp_path: Path) -> None:
         "--force-optional",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "force_optional.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "force_optional.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -778,7 +784,7 @@ def test_main_with_exclusive(tmp_path: Path) -> None:
         str(output_file),
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "with_exclusive.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "with_exclusive.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -791,7 +797,7 @@ def test_main_subclass_enum(tmp_path: Path) -> None:
         str(output_file),
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "subclass_enum.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "subclass_enum.py").read_text()
 
 
 def test_main_use_standard_collections(tmp_path: Path) -> None:
@@ -904,7 +910,7 @@ def test_main_openapi_aware_datetime(output_model: str, expected_output: str, da
         output_model,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 @freeze_time("2019-07-26")
@@ -934,7 +940,7 @@ def test_main_openapi_datetime(output_model: str, expected_output: str, tmp_path
         output_model,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 @freeze_time("2019-07-26")
@@ -973,7 +979,7 @@ def test_main_openapi_enum_models_as_literal_one(min_version: str, tmp_path: Pat
         min_version,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "enum_models" / "one.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "enum_models" / "one.py").read_text()
 
 
 @pytest.mark.skipif(
@@ -997,7 +1003,10 @@ def test_main_openapi_use_one_literal_as_default(min_version: str, tmp_path: Pat
         "--use-one-literal-as-default",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "enum_models" / "one_literal_as_default.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "enum_models" / "one_literal_as_default.py").read_text()
+    )
 
 
 @pytest.mark.skipif(
@@ -1024,7 +1033,7 @@ def test_main_openapi_enum_models_as_literal_all(min_version: str, tmp_path: Pat
         min_version,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "enum_models" / "all.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "enum_models" / "all.py").read_text()
 
 
 @pytest.mark.skipif(
@@ -1052,7 +1061,9 @@ def test_main_openapi_enum_models_as_literal(tmp_path: Path) -> None:
     ])
 
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "enum_models" / "as_literal.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "enum_models" / "as_literal.py").read_text()
+    )
 
 
 @pytest.mark.benchmark
@@ -1068,7 +1079,7 @@ def test_main_openapi_all_of_required(tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "allof_required.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "allof_required.py").read_text()
 
 
 @pytest.mark.benchmark
@@ -1084,7 +1095,7 @@ def test_main_openapi_nullable(tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "nullable.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "nullable.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1100,7 +1111,9 @@ def test_main_openapi_nullable_strict_nullable(tmp_path: Path) -> None:
         "--strict-nullable",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "nullable_strict_nullable.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "nullable_strict_nullable.py").read_text()
+    )
 
 
 @pytest.mark.parametrize(
@@ -1140,9 +1153,9 @@ def test_main_openapi_pattern(output_model: str, expected_output: str, tmp_path:
         output_model,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "pattern" / expected_output).read_text().replace(
-        "pattern.json", "pattern.yaml"
-    )
+    assert output_file.read_text(encoding="utf-8") == (
+        EXPECTED_OPENAPI_PATH / "pattern" / expected_output
+    ).read_text().replace("pattern.json", "pattern.yaml")
 
 
 @pytest.mark.parametrize(
@@ -1178,7 +1191,7 @@ def test_main_openapi_pattern_with_lookaround_pydantic_v2(
         *args,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1231,7 +1244,7 @@ def test_main_http_openapi(mocker: MockerFixture, tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "http_refs.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "http_refs.py").read_text()
     httpx_get_mock.assert_has_calls([
         call(
             "https://example.com/refs.yaml",
@@ -1262,7 +1275,10 @@ def test_main_disable_appending_item_suffix(tmp_path: Path) -> None:
         "--disable-appending-item-suffix",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "disable_appending_item_suffix.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "disable_appending_item_suffix.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -1280,7 +1296,10 @@ def test_main_openapi_body_and_parameters(tmp_path: Path) -> None:
         "schemas",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "body_and_parameters" / "general.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "body_and_parameters" / "general.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -1303,7 +1322,10 @@ def test_main_openapi_body_and_parameters_remote_ref(mocker: MockerFixture, tmp_
         "schemas",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "body_and_parameters" / "remote_ref.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "body_and_parameters" / "remote_ref.py").read_text()
+    )
     httpx_get_mock.assert_has_calls([
         call(
             "https://schema.example",
@@ -1329,7 +1351,10 @@ def test_main_openapi_body_and_parameters_only_paths(tmp_path: Path) -> None:
         "paths",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "body_and_parameters" / "only_paths.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "body_and_parameters" / "only_paths.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -1346,7 +1371,10 @@ def test_main_openapi_body_and_parameters_only_schemas(tmp_path: Path) -> None:
         "schemas",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "body_and_parameters" / "only_schemas.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "body_and_parameters" / "only_schemas.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -1361,7 +1389,7 @@ def test_main_openapi_content_in_parameters(tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "content_in_parameters.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "content_in_parameters.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1379,7 +1407,7 @@ def test_main_openapi_oas_response_reference(tmp_path: Path) -> None:
         "schemas",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "oas_response_reference.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "oas_response_reference.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1394,7 +1422,7 @@ def test_main_openapi_json_pointer(tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "json_pointer.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "json_pointer.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1429,7 +1457,7 @@ def test_main_use_annotated_with_field_constraints(
         output_model,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1444,7 +1472,7 @@ def test_main_nested_enum(tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "nested_enum.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "nested_enum.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1460,7 +1488,7 @@ def test_openapi_special_yaml_keywords(mocker: MockerFixture, tmp_path: Path) ->
         "--validation",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "special_yaml_keywords.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "special_yaml_keywords.py").read_text()
     mock_prance.assert_called_once()
 
 
@@ -1483,7 +1511,7 @@ def test_main_openapi_nullable_use_union_operator(tmp_path: Path) -> None:
     ])
     assert return_code == Exit.OK
     assert (
-        output_file.read_text()
+        output_file.read_text(encoding="utf-8")
         == (EXPECTED_OPENAPI_PATH / "nullable_strict_nullable_use_union_operator.py").read_text()
     )
 
@@ -1515,7 +1543,7 @@ def test_main_collapse_root_models(tmp_path: Path) -> None:
         "--collapse-root-models",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "collapse_root_models.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "collapse_root_models.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1530,7 +1558,10 @@ def test_main_collapse_root_models_field_constraints(tmp_path: Path) -> None:
         "--field-constraints",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "collapse_root_models_field_constraints.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "collapse_root_models_field_constraints.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -1546,7 +1577,7 @@ def test_main_collapse_root_models_with_references_to_flat_types(tmp_path: Path)
 
     assert return_code == Exit.OK
     assert (
-        output_file.read_text()
+        output_file.read_text(encoding="utf-8")
         == (EXPECTED_OPENAPI_PATH / "collapse_root_models_with_references_to_flat_types.py").read_text()
     )
 
@@ -1563,7 +1594,7 @@ def test_main_openapi_max_items_enum(tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "max_items_enum.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "max_items_enum.py").read_text()
 
 
 @pytest.mark.parametrize(
@@ -1593,7 +1624,7 @@ def test_main_openapi_const(output_model: str, expected_output: str, tmp_path: P
         output_model,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 @pytest.mark.parametrize(
@@ -1611,6 +1642,14 @@ def test_main_openapi_const(output_model: str, expected_output: str, tmp_path: P
             "msgspec.Struct",
             "const_field_msgspec.py",
         ),
+        (
+            "typing.TypedDict",
+            "const_field_typed_dict.py",
+        ),
+        (
+            "dataclasses.dataclass",
+            "const_field_dataclass.py",
+        ),
     ],
 )
 @freeze_time("2019-07-26")
@@ -1628,7 +1667,7 @@ def test_main_openapi_const_field(output_model: str, expected_output: str, tmp_p
         "--collapse-root-models",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / expected_output).read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1643,7 +1682,7 @@ def test_main_openapi_complex_reference(tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "complex_reference.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "complex_reference.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1658,7 +1697,10 @@ def test_main_openapi_reference_to_object_properties(tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "reference_to_object_properties.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "reference_to_object_properties.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -1675,7 +1717,7 @@ def test_main_openapi_reference_to_object_properties_collapse_root_models(tmp_pa
     ])
     assert return_code == Exit.OK
     assert (
-        output_file.read_text()
+        output_file.read_text(encoding="utf-8")
         == (EXPECTED_OPENAPI_PATH / "reference_to_object_properties_collapse_root_models.py").read_text()
     )
 
@@ -1693,7 +1735,9 @@ def test_main_openapi_override_required_all_of_field(tmp_path: Path) -> None:
         "--collapse-root-models",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "override_required_all_of.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "override_required_all_of.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -1709,7 +1753,7 @@ def test_main_use_default_kwarg(tmp_path: Path) -> None:
         "--use-default-kwarg",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "use_default_kwarg.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "use_default_kwarg.py").read_text()
 
 
 @pytest.mark.parametrize(
@@ -1737,7 +1781,7 @@ def test_main_openapi_discriminator(input_: str, output: str, tmp_path: Path) ->
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "discriminator" / output).read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "discriminator" / output).read_text()
 
 
 @freeze_time("2023-07-27")
@@ -1775,9 +1819,9 @@ def test_main_openapi_discriminator_in_array(kind: str, option: str | None, expe
         if a
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "discriminator" / expected).read_text().replace(
-        "discriminator_in_array.yaml", input_file
-    )
+    assert output_file.read_text(encoding="utf-8") == (
+        EXPECTED_OPENAPI_PATH / "discriminator" / expected
+    ).read_text().replace("discriminator_in_array.yaml", input_file)
 
 
 @pytest.mark.parametrize(
@@ -1835,7 +1879,7 @@ def test_main_dataclass(tmp_path: Path) -> None:
         "dataclasses.dataclass",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "dataclass.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "dataclass.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1852,7 +1896,7 @@ def test_main_dataclass_base_class(tmp_path: Path) -> None:
         "custom_base.Base",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "dataclass_base_class.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "dataclass_base_class.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1868,7 +1912,10 @@ def test_main_openapi_reference_same_hierarchy_directory(tmp_path: Path) -> None
             "openapi",
         ])
         assert return_code == Exit.OK
-        assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "reference_same_hierarchy_directory.py").read_text()
+        assert (
+            output_file.read_text(encoding="utf-8")
+            == (EXPECTED_OPENAPI_PATH / "reference_same_hierarchy_directory.py").read_text()
+        )
 
 
 @freeze_time("2019-07-26")
@@ -1882,7 +1929,9 @@ def test_main_multiple_required_any_of(tmp_path: Path) -> None:
         "--collapse-root-models",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "multiple_required_any_of.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "multiple_required_any_of.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -1895,7 +1944,7 @@ def test_main_openapi_max_min(tmp_path: Path) -> None:
         str(output_file),
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "max_min_number.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "max_min_number.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1913,7 +1962,9 @@ def test_main_openapi_use_operation_id_as_name(tmp_path: Path) -> None:
         "parameters",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "use_operation_id_as_name.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "use_operation_id_as_name.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -1954,7 +2005,9 @@ def test_main_unsorted_optional_fields(tmp_path: Path) -> None:
         "dataclasses.dataclass",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "unsorted_optional_fields.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "unsorted_optional_fields.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -1969,7 +2022,7 @@ def test_main_typed_dict(tmp_path: Path) -> None:
         "typing.TypedDict",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "typed_dict.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "typed_dict.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -1986,7 +2039,7 @@ def test_main_typed_dict_py(min_version: str, tmp_path: Path) -> None:
         min_version,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "typed_dict_py.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "typed_dict_py.py").read_text()
 
 
 @pytest.mark.skipif(
@@ -2034,7 +2087,7 @@ def test_main_typed_dict_nullable(tmp_path: Path) -> None:
         "3.11",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "typed_dict_nullable.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "typed_dict_nullable.py").read_text()
 
 
 @pytest.mark.skipif(
@@ -2056,7 +2109,10 @@ def test_main_typed_dict_nullable_strict_nullable(tmp_path: Path) -> None:
         "--strict-nullable",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "typed_dict_nullable_strict_nullable.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "typed_dict_nullable_strict_nullable.py").read_text()
+    )
 
 
 @pytest.mark.benchmark
@@ -2076,7 +2132,7 @@ def test_main_openapi_nullable_31(tmp_path: Path) -> None:
         "--use-union-operator",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "nullable_31.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "nullable_31.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -2091,7 +2147,7 @@ def test_main_custom_file_header_path(tmp_path: Path) -> None:
         str(DATA_PATH / "custom_file_header.txt"),
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "custom_file_header.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "custom_file_header.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -2125,7 +2181,7 @@ def test_main_pydantic_v2(tmp_path: Path) -> None:
         "pydantic_v2.BaseModel",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "pydantic_v2.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "pydantic_v2.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -2140,7 +2196,7 @@ def test_main_openapi_custom_id_pydantic_v2(tmp_path: Path) -> None:
         "pydantic_v2.BaseModel",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "custom_id_pydantic_v2.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "custom_id_pydantic_v2.py").read_text()
 
 
 @pytest.mark.skipif(
@@ -2161,7 +2217,10 @@ def test_main_openapi_custom_id_pydantic_v2_custom_base(tmp_path: Path) -> None:
         "custom_base.Base",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "custom_id_pydantic_v2_custom_base.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "custom_id_pydantic_v2_custom_base.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -2188,7 +2247,9 @@ def test_main_openapi_all_of_with_relative_ref(tmp_path: Path) -> None:
         "--use-field-description",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "all_of_with_relative_ref.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "all_of_with_relative_ref.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -2205,7 +2266,7 @@ def test_main_openapi_msgspec_struct(min_version: str, tmp_path: Path) -> None:
         "msgspec.Struct",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "msgspec_struct.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "msgspec_struct.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -2223,7 +2284,9 @@ def test_main_openapi_msgspec_struct_snake_case(min_version: str, tmp_path: Path
         "msgspec.Struct",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "msgspec_struct_snake_case.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "msgspec_struct_snake_case.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -2246,7 +2309,7 @@ def test_main_openapi_msgspec_use_annotated_with_field_constraints(tmp_path: Pat
     ])
     assert return_code == Exit.OK
     assert (
-        output_file.read_text()
+        output_file.read_text(encoding="utf-8")
         == (EXPECTED_OPENAPI_PATH / "msgspec_use_annotated_with_field_constraints.py").read_text()
     )
 
@@ -2267,7 +2330,7 @@ def test_main_openapi_discriminator_one_literal_as_default(tmp_path: Path) -> No
     ])
     assert return_code == Exit.OK
     assert (
-        output_file.read_text()
+        output_file.read_text(encoding="utf-8")
         == (EXPECTED_OPENAPI_PATH / "discriminator" / "enum_one_literal_as_default.py").read_text()
     )
 
@@ -2288,7 +2351,7 @@ def test_main_openapi_discriminator_one_literal_as_default_dataclass(tmp_path: P
     ])
     assert return_code == Exit.OK
     assert (
-        output_file.read_text()
+        output_file.read_text(encoding="utf-8")
         == (EXPECTED_OPENAPI_PATH / "discriminator" / "dataclass_enum_one_literal_as_default.py").read_text()
     )
 
@@ -2314,7 +2377,7 @@ def test_main_openapi_keyword_only_dataclass(tmp_path: Path) -> None:
         "3.10",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "dataclass_keyword_only.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "dataclass_keyword_only.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -2378,7 +2441,7 @@ def test_main_openapi_keyword_only_msgspec(min_version: str, tmp_path: Path) ->
         min_version,
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "msgspec_keyword_only.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "msgspec_keyword_only.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -2404,7 +2467,10 @@ def test_main_openapi_keyword_only_msgspec_with_extra_data(min_version: str, tmp
         str(OPEN_API_DATA_PATH / "extra_data_msgspec.json"),
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "msgspec_keyword_only_omit_defaults.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "msgspec_keyword_only_omit_defaults.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -2429,7 +2495,10 @@ def test_main_generate_openapi_keyword_only_msgspec_with_extra_data(tmp_path: Pa
         use_annotated=True,
         field_constraints=True,
     )
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "msgspec_keyword_only_omit_defaults.py").read_text()
+    assert (
+        output_file.read_text(encoding="utf-8")
+        == (EXPECTED_OPENAPI_PATH / "msgspec_keyword_only_omit_defaults.py").read_text()
+    )
 
 
 @freeze_time("2019-07-26")
@@ -2446,7 +2515,7 @@ def test_main_openapi_referenced_default(tmp_path: Path) -> None:
         "pydantic_v2.BaseModel",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "referenced_default.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "referenced_default.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -2467,7 +2536,7 @@ def test_duplicate_models(tmp_path: Path) -> None:
         "--parent-scoped-naming",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "duplicate_models2.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "duplicate_models2.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -2484,7 +2553,7 @@ def test_main_openapi_shadowed_imports(tmp_path: Path) -> None:
         "pydantic_v2.BaseModel",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "shadowed_imports.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "shadowed_imports.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -2501,7 +2570,7 @@ def test_main_openapi_extra_fields_forbid(tmp_path: Path) -> None:
         "forbid",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "additional_properties.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "additional_properties.py").read_text()
 
 
 @freeze_time("2019-07-26")
@@ -2516,4 +2585,4 @@ def test_main_openapi_same_name_objects(tmp_path: Path) -> None:
         "openapi",
     ])
     assert return_code == Exit.OK
-    assert output_file.read_text() == (EXPECTED_OPENAPI_PATH / "same_name_objects.py").read_text()
+    assert output_file.read_text(encoding="utf-8") == (EXPECTED_OPENAPI_PATH / "same_name_objects.py").read_text()
